@@ -1470,15 +1470,20 @@ const APImethods = {
         "desc": "Sets myMPD settings.",
         "protected": true,
         "params": {
-            "coverimageNames": {
+            "imageNamesSM": {
+                "type": APItypes.string,
+                "example": "folder-sm,cover-sm",
+                "desc": "Comma separated list of coverimages, basenames or full names."
+            },
+            "imageNamesMD": {
                 "type": APItypes.string,
                 "example": "folder,cover",
                 "desc": "Comma separated list of coverimages, basenames or full names."
             },
-            "thumbnailNames": {
+            "imageNamesLG": {
                 "type": APItypes.string,
-                "example": "folder-sm,cover-sm",
-                "desc": "Comma separated list of coverimage thumbnails, basenames or full names."
+                "example": "folder-lg,cover-lg",
+                "desc": "Comma separated list of coverimages, basenames or full names."
             },
             "lastPlayedCount": {
                 "type": APItypes.uint,
@@ -1870,6 +1875,11 @@ const APImethods = {
                 "example": true,
                 "desc": "Ignores hated songs."
             },
+            "jukeboxAutostart": {
+                "type": APItypes.bool,
+                "example": true,
+                "desc": "Starts the jukebox after connection to MPD is established."
+            },
             "jukeboxFilterInclude": APIparams.expression,
             "jukeboxFilterExclude": APIparams.expression,
             "jukeboxMinSongDuration": {
@@ -2519,6 +2529,20 @@ const APImethods = {
         "desc": "Restarts the jukebox.",
         "params": {}
     },
+    "MYMPD_API_JUKEBOX_REFILL": {
+        "desc": "Refills the jukebox queue.",
+        "params": {}
+    },
+    "MYMPD_API_JUKEBOX_REFILL_ADD": {
+        "desc": "Refills the jukebox queue and adds songs to the MPD queue.",
+        "params": {
+            "addSongs": {
+                "type": APItypes.uint,
+                "example": "5",
+                "desc": "Number of songs to add."
+            }
+        }
+    },
     "MYMPD_API_LYRICS_GET": {
         "desc": "Gets all lyrics from uri.",
         "params": {
